@@ -65,7 +65,7 @@ LambdaToSsmstringparameter(
     self, 'test-lambda-ssmstringparameter-stack',
     lambda_function_props=_lambda.FunctionProps(
         code=_lambda.Code.from_asset('lambda'),
-        runtime=_lambda.Runtime.Python_3_11,
+        runtime=_lambda.Runtime.PYTHON_3_11,
         handler='index.handler'
     ),
     string_parameter_props=ssm.StringParameterProps(
